@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2013 Roger Light <roger@atchoo.org>
@@ -59,7 +59,7 @@ def print_usage():
 
 def main(argv):
     debug = False
-    host = "localhost"
+    host = "mqtt.eclipse.org"
     client_id = None
     keepalive = 60
     port = 1883
@@ -71,7 +71,7 @@ def main(argv):
     try:
         opts, args = getopt.getopt(argv, "dh:i:k:p:P:t:u:v",
                                    ["debug", "id", "keepalive", "port", "password", "topic", "username", "verbose"])
-    except getopt.GetoptError as s:
+    except getopt.GetoptError:
         print_usage()
         sys.exit(2)
     for opt, arg in opts:
