@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2014 Roger Light <roger@atchoo.org>
@@ -49,7 +49,7 @@ mqttc.on_disconnect = on_disconnect
 # Uncomment to enable debug messages
 # mqttc.on_log = on_log
 mqttc.user_data_set(0)
-mqttc.connect("test.mosquitto.org", 1883, 60)
+mqttc.connect("mqtt.eclipse.org", 1883, 60)
 
 mqttc.loop_forever()
 
@@ -57,5 +57,5 @@ mqttc.loop_forever()
 mqttc = mqtt.Client(client_id="asdfj", clean_session=True)
 mqttc.on_connect = on_connect
 mqttc.user_data_set(2)
-mqttc.connect("test.mosquitto.org", 1883, 60)
+mqttc.connect("mqtt.eclipse.org", 1883, 60)
 mqttc.loop_forever()
