@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2014 Roger Light <roger@atchoo.org>
@@ -19,4 +19,4 @@ import context  # Ensures paho is in PYTHONPATH
 import paho.mqtt.publish as publish
 
 msgs = [{'topic': "paho/test/multiple", 'payload': "multiple 1"}, ("paho/test/multiple", "multiple 2", 0, False)]
-publish.multiple(msgs, hostname="test.mosquitto.org")
+publish.multiple(msgs, hostname="mqtt.eclipse.org")
