@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2014 Roger Light <roger@atchoo.org>
@@ -18,4 +18,4 @@
 import context  # Ensures paho is in PYTHONPATH
 import paho.mqtt.publish as publish
 
-publish.single("paho/test/single", "boo", hostname="test.mosquitto.org")
+publish.single("paho/test/single", "boo", hostname="mqtt.eclipse.org")
