@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.8
+#!/usr/local/bin/python3.9
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2014 Roger Light <roger@atchoo.org>
@@ -20,4 +20,4 @@ import paho.mqtt.publish as publish
 
 topic = u"paho/test/single/ô"
 payload = u"bôô"
-publish.single(topic, payload, hostname="test.mosquitto.org")
+publish.single(topic, payload, hostname="mqtt.eclipse.org")
