@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2016 Roger Light <roger@atchoo.org>
@@ -21,4 +21,4 @@ import paho.mqtt.subscribe as subscribe
 def print_msg(client, userdata, message):
     print("%s : %s" % (message.topic, message.payload))
 
-subscribe.callback(print_msg, "#", hostname="iot.eclipse.org")
+subscribe.callback(print_msg, "#", hostname="mqtt.eclipse.org")
