@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2016 Roger Light <roger@atchoo.org>
@@ -20,7 +20,7 @@ import paho.mqtt.subscribe as subscribe
 
 topics = ['#']
 
-m = subscribe.simple(topics, hostname="iot.eclipse.org", retained=False, msg_count=2)
+m = subscribe.simple(topics, hostname="mqtt.eclipse.org", retained=False, msg_count=2)
 for a in m:
     print(a.topic)
     print(a.payload)
